@@ -19,6 +19,7 @@ INSTALLED_APPS = [
     'django.contrib.admin',
     'pipeline',
     'tests',
+    'tests.tests'
 ]
 
 ROOT_URLCONF = 'tests.urls'
@@ -50,7 +51,7 @@ PIPELINE_CSS = {
         'source_filenames': (
             'pipeline/css/first.css',
             'pipeline/css/second.css',
-            'pipeline/css/urls.css',
+            'pipeline/css/urls.css'
         ),
         'output_filename': 'screen.css'
     }
